Metadata
========

Metadata represents common metadata of containers and images.

.. autoclass:: conu.apidefs.metadata.Metadata
   :members:

Container specific metadata.

.. autoclass:: conu.apidefs.metadata.ContainerMetadata
   :members:

Image specific metadata.

.. autoclass:: conu.apidefs.metadata.ImageMetadata
   :members:
